==> image-editor_1.0.11.orig.tar.xz: image-editor-1.0.11/libimageviewer/translations/libimageviewer.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Image info</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Basic info</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Details</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>Add to album</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>New album</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>All images</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Open Image</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Export</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Remove from album</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Unfavorite</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorite</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>You have no permission to view the image</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Date modified</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>File size</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Date captured</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Exposure mode</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Exposure program</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Exposure time</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Flash</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Aperture</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Focal length</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Max aperture</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Metering mode</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>White balance</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Flash compensation</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Lens model</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Colorspace</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Camera model</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Dimensions</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Tag</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>Back</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Previous</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Next</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 Size</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Fit to window</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Extract text</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotate counterclockwise</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotate clockwise</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Exit fullscreen</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Fullscreen</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Print</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Slide show</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copy</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Rename</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Show navigation window</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Hide navigation window</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Set as wallpaper</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Display in file manager</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Image info</translation>
    </message>
    <message>
        <source>day</source>
        <translation>day</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Confirm</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Input a new name</translation>
    </message>
    <message>
        <source>The file &quot;%1&quot; already exists, please use another name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Previous</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Play</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Next</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Exit</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>No image files found</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Image file not found</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation>You have no permission to view the file</translation>
    </message>
</context>
</TS>

==> image-editor_1.0.25.orig.tar.xz: image-editor-1.0.25/libimageviewer/translations/libimageviewer.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Image info</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Basic info</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Details</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>Add to album</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>New album</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>All images</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Open Image</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Export</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Remove from album</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Unfavorite</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorite</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>You have no permission to view the image</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Date modified</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>File size</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Date captured</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Exposure mode</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Exposure program</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Exposure time</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Flash</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Aperture</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Focal length</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Max aperture</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Metering mode</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>White balance</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Flash compensation</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Lens model</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Colorspace</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Camera model</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Dimensions</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Tag</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>Back</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Previous</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Next</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 Size</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Fit to window</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Extract text</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rotate counterclockwise</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rotate clockwise</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Delete</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Exit fullscreen</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Fullscreen</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Print</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Slide show</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copy</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Rename</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Show navigation window</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Hide navigation window</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Set as wallpaper</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Display in file manager</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Image info</translation>
    </message>
    <message>
        <source>day</source>
        <translation>day</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation>Photo info</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Confirm</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Input a new name</translation>
    </message>
    <message>
        <source>The file already exists, please use another name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Previous</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Play</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Next</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Exit</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>No image files found</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Image file not found</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation>You have no permission to view the file</translation>
    </message>
</context>
</TS>
